# Future
If you've read up to this point, means that you're having the same pain with Cloud Firestore query. We hope this article motivates you
to try out PyFireSQL. It can be your preferred programming interface to Firestore using Python!

--------

FireSQL has many improvements to be implemented. Just to name a few future improvements, 
- multiple JOIN statements in the FROM clause
- allow OR boolean expression in the WHERE clause
- optimize the query plan before sending queries to Firestore
- support sub-query in SELECT clause

Please join me on the [PyFireSQL](https://github.com/bennycheung/PyFireSQL) open source project, or provide feedbacks to improve FireSQL utilities!
